﻿param (
    [Parameter(Mandatory=$true)]
    [string]$tempDLPath,
    [Parameter(Mandatory=$true)]
    [string]$atriaPkgPath
)

$atriaModules = @('Atria.Tools', 'Atria.Platform')

# Get components that are out of date
$atriaComponents = Get-AtriaComponent -ListOutofDate | Select-Object -ExpandProperty Component
Get-AtriaComponent -ListOutofDate | FT

# Function to download and copy .nupkg files
function Process-Package {
    param (
        [string]$packageName,
        [string]$packageVersion,
        [string]$packagePath,
        [string]$destinationPath
    )

    # Construct the full file path
    $pkgFilename = "$packageName.$packageVersion"
    $fullPath = Join-Path -Path $packagePath -ChildPath $pkgFilename

    # Check if the file already exists in the specified path
    if (-not (Test-Path -Path $fullPath)) {
        Write-Host -ForegroundColor Yellow "Downloading Atria Package: $packageName"
        Get-AtriaPackageFile -Name $packageName -Version $packageVersion -Path $packagePath
    } else {
        Write-Host -ForegroundColor Green "Skipping download of existing Atria Package: $packageName"
    }

    # Search for the .nupkg file in the directory and copy it to the destination path
    $nupkgFile = Get-ChildItem -Path $packagePath -Filter "$packageName.*.nupkg" -Recurse | Where-Object { $_.Name -match "$packageName\.\d+.*\.nupkg" }

    if ($nupkgFile) {
        Write-Host -ForegroundColor Green "Copying $($nupkgFile.FullName) to $destinationPath"
        Copy-Item -Path $nupkgFile.FullName -Destination $destinationPath -Force
    } else {
        Write-Host -ForegroundColor Red "Error: .nupkg file not found in $fullPath"
    }
}

# Ensure the target folder exists
if (-not (Test-Path -Path $atriaPkgPath)) {
    Write-Host -ForegroundColor Red "Target folder $atriaPkgPath does not exist. Creating it."
    New-Item -Path $atriaPkgPath -ItemType Directory
}

# Check if there are any out-of-date components to process
if ($atriaComponents.Count -gt 0) {
    # Process predefined Atria modules
    foreach ($atriaModule in $atriaModules) {
        $atriaMod = Get-AtriaPackage -Name $atriaModule | Select-Object -ExpandProperty Identity

        # Check if the package name contains more than one dot
        if (($atriaMod -split '\.').Count -gt 2) {
            # If it does, split the package name and version at the last dot
            $splitAtriaMod = $atriaMod -split '\.(?=\d)', 2
        } else {
            # If not, split the package name and version at the first digit
            $splitAtriaMod = $atriaMod -split '\d', 2
        }

        # Extract the package name and version
        $atriaModPkgName = $splitAtriaMod[0]
        $atriaModPkgVer = $splitAtriaMod[1]

        # Process the package
        Process-Package -packageName $atriaModPkgName -packageVersion $atriaModPkgVer -packagePath $tempDLPath -destinationPath $atriaPkgPath
    }
    
    # Process out-of-date components
    foreach ($atriaComponent in $atriaComponents) {
        $atriaPkg = Get-AtriaPackage -Name $atriaComponent | Select-Object -ExpandProperty Identity

        # Check if the package name contains more than one dot
        if (($atriaPkg -split '\.').Count -gt 2) {
            # If it does, split the package name and version at the last dot
            $splitAtriaPkg = $atriaPkg -split '\.(?=\d)', 2
        } else {
            # If not, split the package name and version at the first digit
            $splitAtriaPkg = $atriaPkg -split '\d', 2
        }

        # Extract the package name and version
        $atriaPkgName = $splitAtriaPkg[0]
        $atriaPkgVer = $splitAtriaPkg[1]

        # Process the package
        Process-Package -packageName $atriaPkgName -packageVersion $atriaPkgVer -packagePath $tempDLPath -destinationPath $atriaPkgPath
    }
    
} else {
    Write-Host -ForegroundColor Cyan "No out-of-date components found. Script execution complete."
}
